@@ -21,7 +21,6 @@
 #' @param return_calls Logical. Default is `FALSE`. If `TRUE`, the calls are returned
 #' as a list of expressions.
 #' @param ... Arguments passed on to [gt::gt]
-#' @param exclude DEPRECATED.
 #' @return A `gt_tbl` object
 #' @family gtsummary output types
 #' @author Daniel D. Sjoberg
@@ -40,22 +39,8 @@
 #' `r man_create_image_tag(file = "as_gt_ex1.png", width = "50")`
 #' }}
 
-as_gt <- function(x, include = everything(), return_calls = FALSE, ...,
-                  exclude = NULL) {
+as_gt <- function(x, include = everything(), return_calls = FALSE, ...) {
   .assert_class(x, "gtsummary")
-  # making list of commands to include -----------------------------------------
-  if (!rlang::quo_is_null(rlang::enquo(exclude))) {
-    lifecycle::deprecate_stop(
-      "1.2.5",
-      "gtsummary::as_gt(exclude = )",
-      "as_gt(include = )",
-      details = paste0(
-        "The `include` argument accepts quoted and unquoted expressions similar\n",
-        "to `dplyr::select()`. To exclude commands, use the minus sign.\n",
-        "For example, `include = -tab_spanner`"
-      )
-    )
-  }
 
   # running pre-conversion function, if present --------------------------------
   x <- do.call(get_theme_element("pkgwide-fun:pre_conversion", default = identity), list(x))
@@ -95,7 +80,6 @@ as_gt <- function(x, include = everything(), return_calls = FALSE, ...,
     )
 
   # user cannot omit the first 'gt' command
-  include <- include %>% setdiff(exclude)
   include <- "gt" %>% union(include)
 
   # return calls, if requested -------------------------------------------------
@@ -105,8 +89,8 @@ as_gt <- function(x, include = everything(), return_calls = FALSE, ...,
 
   # taking each gt function call, concatenating them with %>% separating them
   gt_calls[include] %>%
-  c(parse_expr(.get_deprecated_option("gtsummary.as_gt.addl_cmds", default = "NULL"))) %>%
-  .eval_list_of_exprs()
+    c(parse_expr(.get_deprecated_option("gtsummary.as_gt.addl_cmds", default = "NULL"))) %>%
+    .eval_list_of_exprs()
 }
 
 # creating gt calls from table_styling -----------------------------------------
@@ -115,11 +99,16 @@ table_styling_to_gt_calls <- function(x, ...) {
 
   # gt -------------------------------------------------------------------------
   groupname_col <-
-    switch("groupname_col" %in% x$table_styling$header$column, "groupname_col")
+    switch("groupname_col" %in% x$table_styling$header$column,
+      "groupname_col"
+    )
   caption <-
     switch(!is.null(x$table_styling$caption),
-           rlang::call2(attr(x$table_styling$caption, "text_interpret"),
-                        x$table_styling$caption))
+      rlang::call2(
+        attr(x$table_styling$caption, "text_interpret"),
+        x$table_styling$caption
+      )
+    )
   gt_calls[["gt"]] <-
     expr(gt::gt(
       data = x$table_body,
@@ -244,8 +233,7 @@ table_styling_to_gt_calls <- function(x, ...) {
   if (nrow(x$table_styling$footnote) == 0 &&
     nrow(x$table_styling$footnote_abbrev) == 0) {
     gt_calls[["tab_footnote"]] <- list()
-  }
-  else {
+  } else {
     df_footnotes <-
       bind_rows(
         x$table_styling$footnote,
@@ -304,7 +292,7 @@ table_styling_to_gt_calls <- function(x, ...) {
         .data$interpret_spanning_header, .data$spanning_header,
         ~ call2(parse_expr(.x), .y)
       ),
-      cols = map(.data$cols, ~pull(.x))
+      cols = map(.data$cols, ~ pull(.x))
     ) %>%
     select("spanning_header", "cols")
 
@@ -340,10 +328,12 @@ table_styling_to_gt_calls <- function(x, ...) {
   gt_calls[["cols_hide"]] <-
     names(x$table_body) %>%
     setdiff(.cols_to_show(x)) %>%
-    {.purrr_when(
-      rlang::is_empty(.) ~ NULL,
-      TRUE ~ expr(gt::cols_hide(columns = !!.))
-    )}
+    {
+      .purrr_when(
+        rlang::is_empty(.) ~ NULL,
+        TRUE ~ expr(gt::cols_hide(columns = !!.))
+      )
+    }
 
   # return list of gt expressions
   gt_calls
