@@ -92,9 +92,6 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
                              hide_n = FALSE, show_single_row = NULL, conf.level = NULL,
                              estimate_fun = NULL, pvalue_fun = NULL, formula = "{y} ~ {x}",
                              add_estimate_to_reference_rows = NULL, conf.int = NULL, ...) {
-  # deprecated arguments -------------------------------------------------------
-  .tbl_regression_deprecated_arguments(...)
-
   # checking input -------------------------------------------------------------
   # data is a data frame
   if (!is.data.frame(data) && !is_survey(data)) {
@@ -136,29 +133,35 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   y <- rlang::enexpr(y)
   x <-
     switch(!is.null(x),
-           tryCatch({
-             .select_to_varnames(
-               select = !!x,
-               data = .extract_data_frame(data),
-               arg_name = "x"
-             ) %>%
-               rlang::sym()},
-             error = function(e) x
-           ) %>%
-             rlang::quo_text())
+      tryCatch(
+        {
+          .select_to_varnames(
+            select = !!x,
+            data = .extract_data_frame(data),
+            arg_name = "x"
+          ) %>%
+            rlang::sym()
+        },
+        error = function(e) x
+      ) %>%
+        rlang::quo_text()
+    )
 
   y <-
     switch(!is.null(y),
-           tryCatch({
-             .select_to_varnames(
-               select = !!y,
-               data = .extract_data_frame(data),
-               arg_name = "y"
-             ) %>%
-               rlang::sym()},
-             error = function(e) y
-           ) %>%
-             rlang::quo_text())
+      tryCatch(
+        {
+          .select_to_varnames(
+            select = !!y,
+            data = .extract_data_frame(data),
+            arg_name = "y"
+          ) %>%
+            rlang::sym()
+        },
+        error = function(e) y
+      ) %>%
+        rlang::quo_text()
+    )
 
   # checking selections of x and y
   if (is.null(x) + is.null(y) != 1L) {
@@ -226,6 +229,7 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   # will return call, and all object passed to in table1 call
   # the object func_inputs is a list of every object passed to the function
   tbl_uvregression_inputs <- as.list(environment())
+  dots <- rlang::enquos(...)
   tbl_uvregression_inputs <-
     tbl_uvregression_inputs[!names(tbl_uvregression_inputs) %in% c("x_name", "y_name")]
 
@@ -318,7 +322,8 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   df_model$tbl <- pmap(
     list(df_model$tbl_args, df_model$type, df_model$y),
     function(tbl_args, type, y) {
-      tbl <- call2(tbl_regression, !!!tbl_args) %>% eval()
+      # browser()
+      tbl <- call2(tbl_regression, !!!tbl_args, !!!dots) %>% eval()
       if (type == "y_varies") {
         tbl$table_body$variable <- y
         tbl$table_body$var_type <- NA_character_
@@ -333,8 +338,9 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   class(results) <- c("tbl_uvregression", "gtsummary")
 
   # update column header if `x=` was used --------------------------------------
-  if (!is.null(x))
+  if (!is.null(x)) {
     results <- modify_table_styling(results, columns = "label", label = "**Outcome**")
+  }
 
   # creating a meta_data table -------------------------------------------------
   # (this will be used in subsequent functions, eg add_global_p)
