@@ -32,14 +32,16 @@
     df <-
       df %>%
       filter(.data$test_name %in% .env$test)
-  }
-  else if (rlang::is_function(test)) { # test function passed ------------------
+  } else if (rlang::is_function(test)) { # test function passed ------------------
     df <-
       df %>%
       # now select test object equivalent to the passed function
-      filter(map_lgl(.data$test_fun,
-                     ~tryCatch(identical(eval(.x), test),
-                               error = function(e) FALSE)))
+      filter(map_lgl(
+        .data$test_fun,
+        ~ tryCatch(identical(eval(.x), test),
+          error = function(e) FALSE
+        )
+      ))
   }
 
   # return info from df if internal test selected
@@ -299,34 +301,34 @@
   }
 
   if (summary_type %in% c("continuous", "continuous2") &&
-      is.null(group) && is.null(adj.vars) && is.data.frame(data)) {
+    is.null(group) && is.null(adj.vars) && is.data.frame(data)) {
     return("t.test")
   }
-  if (summary_type %in% c("continuous", "continuous2")
-      && is.null(group) && is.data.frame(data)) {
+  if (summary_type %in% c("continuous", "continuous2") &&
+    is.null(group) && is.data.frame(data)) {
     return("ancova")
   }
   if (summary_type %in% "dichotomous" && is.null(group) &&
-      is.null(adj.vars) && is.data.frame(data)) {
+    is.null(adj.vars) && is.data.frame(data)) {
     return("prop.test")
   }
   if (summary_type %in% "categorical" && is.null(group) &&
-      is.null(adj.vars) && is.data.frame(data)) {
+    is.null(adj.vars) && is.data.frame(data)) {
     return("smd")
   }
 
   if (summary_type %in% c("continuous", "continuous2") &&
-      !is.null(group) && is.data.frame(data)) {
+    !is.null(group) && is.data.frame(data)) {
     return("ancova_lme4")
   }
 
   if (summary_type %in% c("continuous", "continuous2", "dichotomous") &&
-      is.null(group) && is_survey(data)) {
+    is.null(group) && is_survey(data)) {
     return("emmeans")
   }
 
   if (summary_type %in% c("categorical") &&
-      is.null(adj.vars) && is.null(group) && is_survey(data)) {
+    is.null(adj.vars) && is.null(group) && is_survey(data)) {
     return("smd")
   }
 
