@@ -48,12 +48,16 @@
   x$table_styling$text_format <-
     .purrr_when(
       isTRUE(all(c("label", "row_type") %in% x$table_styling$header$column)) ~
-        tibble(column = "label",
-               rows = list(rlang::expr(.data$row_type %in% c("level", "missing"))),
-               format_type = "indent", undo_text_format = FALSE),
+        tibble(
+          column = "label",
+          rows = list(rlang::expr(.data$row_type %in% c("level", "missing"))),
+          format_type = "indent", undo_text_format = FALSE
+        ),
       isFALSE(all(c("label", "row_type") %in% x$table_styling$header$column)) ~
-        tibble(column = character(), rows = list(),
-               format_type = character(), undo_text_format = logical())
+        tibble(
+          column = character(), rows = list(),
+          format_type = character(), undo_text_format = logical()
+        )
     )
 
   x$table_styling$fmt_missing <-
@@ -73,7 +77,6 @@
 
 # this fn updates `table_styling` list to match `table_body`
 .update_table_styling <- function(x) {
-
   # vector of columns deleted in update
   deleted_columns <-
     x$table_styling$header$column %>%
@@ -84,7 +87,7 @@
     for (styling_element in names(x$table_styling)) {
       # if element is a tibble with a column called 'column'
       if (is.data.frame(x$table_styling[[styling_element]]) &&
-          "column" %in% names(x$table_styling[[styling_element]])) {
+        "column" %in% names(x$table_styling[[styling_element]])) {
         x$table_styling[[styling_element]] <-
           x$table_styling[[styling_element]] %>%
           filter(!.data$column %in% deleted_columns)
@@ -110,7 +113,7 @@
 }
 
 .rows_update_table_styling_header <- function(x, y) {
-  common_columns <-intersect(names(x), names(y))
+  common_columns <- intersect(names(x), names(y))
 
   x %>%
     # updating rows in header
@@ -129,7 +132,7 @@
 .purrr_when <- function(...) {
   lst_formulas <- rlang::dots_list(...)
 
-  for(i in seq_len(length(lst_formulas))) {
+  for (i in seq_len(length(lst_formulas))) {
     if (isTRUE(eval_tidy(.f_lhs_as_quo(lst_formulas[[i]])))) {
       return(eval_tidy(.f_rhs_as_quo(lst_formulas[[i]])))
     }
