@@ -1,26 +1,23 @@
 skip_on_cran()
-library(dplyr)
 
 test_that("add_p creates output without error/warning", {
-  expect_error(
-    tbl_summary(trial, by = grade) %>% add_p(),
-    NA
+  expect_snapshot(
+    tbl_summary(trial, by = grade) %>% add_p() %>% render_as_html()
   )
 
-  expect_error(
-    tbl_summary(mtcars, by = am) %>% add_p(),
-    NA
-  )
+  tbl <- tbl_summary(mtcars, by = am) %>%
+    add_p() %>%
+    as_tibble()
+  expect_snapshot(tbl)
   expect_warning(
     tbl_summary(mtcars, by = am) %>% add_p(),
     NA
   )
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       tbl_summary(by = trt) %>%
-      add_p(),
-    NA
+      add_p() %>% render_as_html()
   )
 
   expect_warning(
@@ -37,10 +34,9 @@ test_that("add_p creates output without error/warning", {
     NA
   )
 
-  expect_error(
+  expect_snapshot(
     tbl_summary(trial, by = trt, include = -response) %>%
-      add_p(group = response),
-    NA
+      add_p(group = response) %>% render_as_html()
   )
 })
 
@@ -61,25 +57,23 @@ test_that("add_p & lme4", {
 })
 
 test_that("add_p creates output without error/warning for continuous2", {
-  expect_error(
-    tbl_summary(trial, by = grade, type = all_continuous() ~ "continuous2") %>% add_p(),
-    NA
+  expect_snapshot(
+    tbl_summary(trial, by = grade, type = all_continuous() ~ "continuous2") %>% add_p() %>% as_tibble()
   )
 
-  expect_error(
-    tbl_summary(mtcars, by = am, type = all_continuous() ~ "continuous2") %>% add_p(),
-    NA
-  )
+  tbl <- tbl_summary(mtcars, by = am, type = all_continuous() ~ "continuous2") %>%
+    add_p() %>%
+    as_tibble()
+  expect_snapshot(tbl)
   expect_warning(
     tbl_summary(mtcars, by = am, type = all_continuous() ~ "continuous2") %>% add_p(),
     NA
   )
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       tbl_summary(by = trt, type = all_continuous() ~ "continuous2") %>%
-      add_p(),
-    NA
+      add_p() %>% render_as_html()
   )
 
   expect_warning(
@@ -96,10 +90,9 @@ test_that("add_p creates output without error/warning for continuous2", {
     NA
   )
 
-  expect_error(
+  expect_snapshot(
     tbl_summary(trial, by = trt, include = -response, type = all_continuous() ~ "continuous2") %>%
-      add_p(group = response),
-    NA
+      add_p(group = response) %>% render_as_html()
   )
 })
 
@@ -120,24 +113,35 @@ test_that("add_p creates errors with bad args", {
 
 test_that("add_p works well", {
   expect_error(
-    tbl_summary(mtcars, by = am) %>%
-      add_p(test = list(
-        vars(mpg) ~ "t.test",
-        disp ~ "aov",
-        hp ~ "oneway.test",
-        cyl ~ "chisq.test.no.correct"
-      )),
+    tbl <-
+      tbl_summary(mtcars, by = am) %>%
+      add_p(
+        test = list(
+          vars(mpg) ~ "t.test",
+          disp ~ "aov",
+          hp ~ "oneway.test",
+          cyl ~ "chisq.test.no.correct",
+          carb ~ "mood.test"
+        )
+      ) %>%
+      as_tibble(),
     NA
   )
+  expect_snapshot(tbl)
 
   expect_error(
-    tbl_summary(mtcars, by = am) %>%
-      add_p(test = list(
-        vars(mpg) ~ t.test,
-        disp ~ aov
-      )),
+    tbl <-
+      tbl_summary(mtcars, by = am) %>%
+      add_p(
+        test = list(
+          vars(mpg) ~ t.test,
+          disp ~ aov
+        )
+      ) %>%
+      as_tibble(),
     NA
   )
+  expect_snapshot(tbl)
 })
 
 test_that("add_p with custom p-value function", {
@@ -152,17 +156,15 @@ test_that("add_p with custom p-value function", {
     stats::mcnemar.test(data[[variable]], data[[by]])$p.value
   }
 
-  expect_error(
+  expect_snapshot(
     trial[c("response", "trt")] %>%
       tbl_summary(by = trt) %>%
-      add_p(test = response ~ "my_mcnemar"),
-    NA
+      add_p(test = response ~ "my_mcnemar") %>% render_as_html()
   )
-  expect_error(
+  expect_snapshot(
     trial[c("response", "trt")] %>%
       tbl_summary(by = trt) %>%
-      add_p(test = response ~ "my_mcnemar2"),
-    NA
+      add_p(test = response ~ "my_mcnemar2") %>% render_as_html()
   )
 
   expect_error(
@@ -172,6 +174,7 @@ test_that("add_p with custom p-value function", {
       add_p(test = response ~ my_mcnemar),
     NA
   )
+  expect_snapshot(tbl_mcnemar %>% render_as_html())
 
   expect_equal(
     tbl_mcnemar$meta_data$p.value,
@@ -194,13 +197,13 @@ test_that("Wilcoxon and Kruskal-Wallis p-values match ", {
 
 trial_group <-
   trial %>%
-  group_by(trt) %>%
-  mutate(id = row_number()) %>%
-  ungroup()
+  dplyr::group_by(trt) %>%
+  dplyr::mutate(id = row_number()) %>%
+  dplyr::ungroup()
 trial_group_wide <-
   trial_group %>%
-  filter(trt == "Drug A") %>%
-  full_join(
+  dplyr::filter(trt == "Drug A") %>%
+  dplyr::full_join(
     trial_group %>%
       filter(trt == "Drug B"),
     by = "id"
@@ -209,20 +212,20 @@ trial_group_wide <-
 test_that("p-values are replicated within tbl_summary()", {
   tbl_test.args <-
     trial %>%
-    select(trt,
-           var_t.test = age,
-           var_t.test_dots = age,
-           var_kruskal.test = age,
-           var_wilcox.test = age,
-           var_wilcox.test_dots = age,
-           var_aov = age,
-           var_chisq.test = response,
-           var_chisq.test_dots = response,
-           var_chisq.test.no.correct = response,
-           var_fisher.test = response,
-           var_fisher.test_dots = response,
-           var_mcnemar.test = response,
-           var_mcnemar.test_dots = response,
+    dplyr::select(trt,
+      var_t.test = age,
+      var_t.test_dots = age,
+      var_kruskal.test = age,
+      var_wilcox.test = age,
+      var_wilcox.test_dots = age,
+      var_aov = age,
+      var_chisq.test = response,
+      var_chisq.test_dots = response,
+      var_chisq.test.no.correct = response,
+      var_fisher.test = response,
+      var_fisher.test_dots = response,
+      var_mcnemar.test = response,
+      var_mcnemar.test_dots = response,
     ) %>%
     tbl_summary(by = trt, missing = "no") %>%
     add_p(
@@ -244,71 +247,72 @@ test_that("p-values are replicated within tbl_summary()", {
         var_mcnemar.test_dots = list(correct = FALSE)
       )
     )
+  expect_snapshot(tbl_test.args %>% render_as_html())
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_t.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_t.test")$p.value,
     t.test(age ~ as.factor(trt), data = trial)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_t.test_dots")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_t.test_dots")$p.value,
     t.test(age ~ as.factor(trt), data = trial, var.equal = TRUE)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_kruskal.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_kruskal.test")$p.value,
     kruskal.test(trial$age, as.factor(trial$trt))$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_wilcox.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_wilcox.test")$p.value,
     wilcox.test(age ~ trt, data = trial)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_wilcox.test_dots")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_wilcox.test_dots")$p.value,
     wilcox.test(age ~ trt, data = trial, correct = FALSE)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_aov")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_aov")$p.value,
     stats::aov(age ~ as.factor(trt), data = trial) %>%
       summary() %>%
       pluck(1, "Pr(>F)", 1)
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_chisq.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_chisq.test")$p.value,
     stats::chisq.test(x = trial[["response"]], y = as.factor(trial[["trt"]]))$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_chisq.test_dots")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_chisq.test_dots")$p.value,
     stats::chisq.test(x = trial[["response"]], y = as.factor(trial[["trt"]]), correct = FALSE)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_chisq.test.no.correct")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_chisq.test.no.correct")$p.value,
     stats::chisq.test(x = trial[["response"]], y = as.factor(trial[["trt"]]), correct = FALSE)$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_fisher.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_fisher.test")$p.value,
     fisher.test(trial[["response"]], as.factor(trial[["trt"]]))$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_fisher.test_dots")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_fisher.test_dots")$p.value,
     fisher.test(trial[["response"]], as.factor(trial[["trt"]]), alternative = "greater")$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_mcnemar.test")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_mcnemar.test")$p.value,
     mcnemar.test(trial[["response"]], as.factor(trial[["trt"]]))$p.value
   )
 
   expect_equal(
-    filter(tbl_test.args$meta_data, variable == "var_mcnemar.test_dots")$p.value,
+    dplyr::filter(tbl_test.args$meta_data, variable == "var_mcnemar.test_dots")$p.value,
     mcnemar.test(trial[["response"]], as.factor(trial[["trt"]]), correct = FALSE)$p.value
   )
 
@@ -322,8 +326,10 @@ test_that("p-values are replicated within tbl_summary()", {
     trial_group %>%
       dplyr::filter(dplyr::row_number() != 1L) %>%
       tbl_summary(include = c(marker, age), by = trt) %>%
-      add_p(test = list(age = "paired.t.test", marker = "paired.wilcox.test"),
-            include = age, group = id)
+      add_p(
+        test = list(age = "paired.t.test", marker = "paired.wilcox.test"),
+        include = age, group = id
+      )
   )
 
 
@@ -349,45 +355,47 @@ test_that("p-values are replicated within tbl_summary()", {
       ),
       test.args = list(
         age_paired.t.test_dots ~ list(mu = 1),
-        response_mcnemar.test_dots ~ list(correct  = FALSE),
+        response_mcnemar.test_dots ~ list(correct = FALSE),
         age_paired.wilcox.test_dots ~ list(mu = 1)
       ),
       group = "id"
     )
+  expect_snapshot(tbl_groups %>% render_as_html())
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "response_mcnemar.test_dots")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "response_mcnemar.test_dots")$p.value,
     mcnemar.test(trial_group_wide[["response.x"]], trial_group_wide[["response.y"]],
-                 correct  = FALSE)$p.value
+      correct = FALSE
+    )$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "response_mcnemar.test")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "response_mcnemar.test")$p.value,
     mcnemar.test(trial_group_wide[["response.x"]], trial_group_wide[["response.y"]])$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "grade_mcnemar.test")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "grade_mcnemar.test")$p.value,
     mcnemar.test(trial_group_wide[["grade.x"]], trial_group_wide[["grade.y"]])$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "age_paired.t.test")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "age_paired.t.test")$p.value,
     t.test(trial_group_wide[["age.x"]], trial_group_wide[["age.y"]], paired = TRUE)$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "age_paired.t.test_dots")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "age_paired.t.test_dots")$p.value,
     t.test(trial_group_wide[["age.x"]], trial_group_wide[["age.y"]], paired = TRUE, mu = 1)$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "age_paired.wilcox.test")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "age_paired.wilcox.test")$p.value,
     wilcox.test(trial_group_wide[["age.x"]], trial_group_wide[["age.y"]], paired = TRUE)$p.value
   )
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "age_paired.wilcox.test_dots")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "age_paired.wilcox.test_dots")$p.value,
     wilcox.test(trial_group_wide[["age.x"]], trial_group_wide[["age.y"]], paired = TRUE, mu = 1)$p.value
   )
 })
@@ -399,16 +407,17 @@ test_that("Groups arg and lme4", {
   tbl_groups <-
     trial_group %>%
     select(trt, id,
-           age_lme4 = age
+      age_lme4 = age
     ) %>%
     tbl_summary(by = trt, missing = "no", include = -id) %>%
     add_p(
       test = list(contains("lme4") ~ "lme4"),
       group = "id"
     )
+  expect_snapshot(tbl_groups %>% render_as_html())
 
   expect_equal(
-    filter(tbl_groups$meta_data, variable == "age_lme4")$p.value,
+    dplyr::filter(tbl_groups$meta_data, variable == "age_lme4")$p.value,
     lme4::glmer(factor(trt) ~ (1 | id), tidyr::drop_na(trial_group, trt, age, id), family = binomial) %>%
       anova(lme4::glmer(factor(trt) ~ age + (1 | id), tidyr::drop_na(trial_group, trt, age, id), family = binomial)) %>%
       pluck("Pr(>Chisq)", 2)
@@ -418,11 +427,11 @@ test_that("Groups arg and lme4", {
 test_that("difftime works with Wilcox", {
   expect_equal(
     trial %>%
-      mutate(
+      dplyr::mutate(
         time_diff = as.difftime(age, units = "mins")
       ) %>%
-      select(trt, time_diff) %>%
-      tbl_summary(by=trt) %>%
+      dplyr::select(trt, time_diff) %>%
+      tbl_summary(by = trt) %>%
       add_p() %>%
       inline_text(variable = time_diff, column = "p.value"),
     "p=0.7"
@@ -433,11 +442,12 @@ test_that("no error with missing data", {
   expect_message(
     t1 <-
       mtcars %>%
-      mutate(mpg = NA, hp = NA, has_banana = factor(NA, levels = c("Yes", "No"))) %>%
-      select(has_banana, mpg, hp, am) %>%
+      dplyr::mutate(mpg = NA, hp = NA, has_banana = factor(NA, levels = c("Yes", "No"))) %>%
+      dplyr::select(has_banana, mpg, hp, am) %>%
       tbl_summary(by = "am", type = hp ~ "continuous") %>%
       add_p()
   )
+  expect_snapshot(t1 %>% render_as_html())
   expect_equal(
     t1 %>% as_tibble(col_labels = FALSE) %>% dplyr::pull(p.value),
     rep_len(NA_character_, 8)
@@ -484,16 +494,19 @@ test_that("add_p can be run after add_difference()", {
       as_tibble(col_labels = FALSE),
     NA
   )
+  expect_snapshot(tbl)
 
   expect_equal(
     tbl %>%
       unlist(),
-    c(label = "Age",
+    c(
+      label = "Age",
       stat_1 = "47.011",
       stat_2 = "47.449",
       estimate = "-0.03",
       ci = "-0.32, 0.25",
-      p.value = "0.8")
+      p.value = "0.8"
+    )
   )
   expect_true(
     tbl %>%
@@ -501,6 +514,4 @@ test_that("add_p can be run after add_difference()", {
       names() %>%
       rlang::is_empty()
   )
-
-
 })
