@@ -6,16 +6,15 @@ strial <- trial %>%
 d <- survey::svydesign(~1, data = as.data.frame(Titanic), weights = ~Freq)
 
 test_that("add_p creates output without error/warning", {
-  expect_error(
-    tbl_svysummary(strial, by = grade) %>% add_p(),
-    NA
+  expect_snapshot(
+    tbl_svysummary(strial, by = grade) %>% add_p() %>% render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     strial %>%
       tbl_svysummary(by = trt) %>%
-      add_p(),
-    NA
+      add_p() %>%
+      render_as_html()
   )
 
   expect_warning(
@@ -45,16 +44,17 @@ test_that("add_p creates output without error/warning", {
 
 
 test_that("add_p creates output without error/warning with continuous2", {
-  expect_error(
-    tbl_svysummary(strial, by = grade, type = all_continuous() ~ "continuous2") %>% add_p(),
-    NA
+  expect_snapshot(
+    tbl_svysummary(strial, by = grade, type = all_continuous() ~ "continuous2") %>%
+      add_p() %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     strial %>%
       tbl_svysummary(by = trt, type = all_continuous() ~ "continuous2") %>%
-      add_p(),
-    NA
+      add_p() %>%
+      render_as_html()
   )
 
   expect_warning(
@@ -116,6 +116,7 @@ test_that("add_p works well", {
       )),
     NA
   )
+  expect_snapshot(tbl1 %>% render_as_html())
 
   expect_equal(
     dplyr::filter(tbl1$meta_data, variable == "age")$p.value,
@@ -160,7 +161,7 @@ test_that("add_p works well", {
       )),
     NA
   )
-
+  expect_snapshot(tbl2 %>% render_as_html())
   expect_error(as_flex_table(tbl2), NA)
 
   expect_equal(
