@@ -10,10 +10,10 @@ tbl2 <-
 
 
 test_that("works as expected without error", {
-  expect_error(
+  expect_snapshot(
     tbl1 %>%
-      add_significance_stars(hide_ci = FALSE, hide_p = FALSE),
-    NA
+      add_significance_stars(hide_ci = FALSE, hide_p = FALSE) %>%
+      render_as_html()
   )
 
   expect_error(
@@ -22,6 +22,7 @@ test_that("works as expected without error", {
       add_significance_stars(hide_ci = FALSE, hide_p = FALSE),
     NA
   )
+  expect_snapshot(tbl_stars %>% render_as_html())
 
   expect_error(
     tbl_merge(list(tbl_stars, tbl_stars)),
@@ -33,13 +34,13 @@ test_that("works as expected without error", {
     c("52", "-58**", "52", "-58**")
   )
 
-  expect_error(
+  expect_snapshot(
     tbl1 %>%
       add_significance_stars(
         thresholds = c(0.0000001, 0.55, 0.9, 1),
         hide_p = FALSE
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   expect_equal(
