@@ -2,32 +2,32 @@ skip_on_cran()
 skip_if_not(broom.helpers::.assert_package("car", pkg_search = "gtsummary", boolean = TRUE))
 
 test_that("no errors/warnings with standard", {
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + grade, trial) %>%
       tbl_regression() %>%
-      add_vif(),
-    NA
+      add_vif() %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + response, trial) %>%
       tbl_regression() %>%
-      add_vif(),
-    NA
+      add_vif() %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + grade, trial) %>%
       tbl_regression() %>%
-      add_vif(statistic = "aGVIF"),
-    NA
+      add_vif(statistic = "aGVIF") %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + grade, trial) %>%
       tbl_regression() %>%
-      add_vif(statistic = c("aGVIF", "df")),
-    NA
+      add_vif(statistic = c("aGVIF", "df")) %>%
+      render_as_html()
   )
 
   expect_error(
@@ -37,17 +37,17 @@ test_that("no errors/warnings with standard", {
     "*"
   )
 
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + response, trial) %>%
       tbl_regression() %>%
-      add_vif(statistic = "VIF"),
-    NA
+      add_vif(statistic = "VIF") %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + response, trial) %>%
       tbl_regression() %>%
-      add_vif(statistic = "VIF"),
-    NA
+      add_vif(statistic = "VIF") %>%
+      render_as_html()
   )
 })
