@@ -4,7 +4,6 @@ skip_if_not(broom.helpers::.assert_package("Hmisc", pkg_search = "gtsummary", bo
 skip_if_not(broom.helpers::.assert_package("geepack", pkg_search = "gtsummary", boolean = TRUE))
 skip_if_not(broom.helpers::.assert_package("survival", pkg_search = "gtsummary", boolean = TRUE))
 
-library(Hmisc)
 mod1 <- lm(
   age ~ marker + I(marker^2) + stage,
   trial[c("age", "marker", "stage")] %>% na.omit()
@@ -12,7 +11,7 @@ mod1 <- lm(
 
 # adding splines
 mod2 <- lm(
-  age ~ rcspline.eval(marker, inclx = TRUE) + stage,
+  age ~ Hmisc::rcspline.eval(marker, inclx = TRUE) + stage,
   trial[c("age", "marker", "stage")] %>% na.omit()
 )
 mod_reduce <- lm(
@@ -29,15 +28,17 @@ test_that("combine_terms works without error", {
       ),
     NA
   )
+  expect_snapshot(tbl1 %>% render_as_html())
 
   expect_error(
     tbl2 <- tbl_regression(mod2, label = stage ~ "Stage") %>%
       combine_terms(
-        formula_update = . ~ . - rcspline.eval(marker, inclx = TRUE),
+        formula_update = . ~ . - Hmisc::rcspline.eval(marker, inclx = TRUE),
         label = "Marker (non-linear terms)"
       ),
     NA
   )
+  expect_snapshot(tbl2 %>% render_as_html())
 
   # testing anova p-value is correct
   expect_equal(
@@ -58,20 +59,20 @@ test_that("combine_terms works without error", {
   )
 
   # works after add_global_p()
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + I(marker^2) + stage, na.omit(trial)) %>%
       tbl_regression() %>%
       add_global_p() %>%
-      combine_terms(formula = . ~ . - marker - I(marker^2)),
-    NA
+      combine_terms(formula = . ~ . - marker - I(marker^2)) %>%
+      render_as_html()
   )
 
   # Confirm logistic regression model works (test option must be specified)
-  expect_error(
+  expect_snapshot(
     glm(response ~ age + marker + sp2marker + sp3marker,
       data = trial %>%
         bind_cols(
-          rcspline.eval(.$marker, nk = 4, inclx = FALSE, norm = 0) %>%
+          Hmisc::rcspline.eval(.$marker, nk = 4, inclx = FALSE, norm = 0) %>%
             as.data.frame() %>%
             set_names("sp2marker", "sp3marker")
         ) %>%
@@ -82,37 +83,37 @@ test_that("combine_terms works without error", {
       combine_terms(
         formula_update = . ~ . - marker - sp2marker - sp3marker,
         test = "LRT"
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   # Confirm Cox model works
-  expect_error(
-    survival::coxph(survival::Surv(ttdeath, death) ~ grade + rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0),
+  expect_snapshot(
+    survival::coxph(survival::Surv(ttdeath, death) ~ grade + Hmisc::rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0),
       data = na.omit(trial)
     ) %>%
       tbl_regression() %>%
       combine_terms(
-        formula_update = . ~ . - rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0)
-      ),
-    NA
+        formula_update = . ~ . - Hmisc::rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0)
+      ) %>%
+      render_as_html()
   )
 
   # Confirm survreg model works
-  expect_error(
-    survival::survreg(survival::Surv(ttdeath, death) ~ grade + rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0),
+  expect_snapshot(
+    survival::survreg(survival::Surv(ttdeath, death) ~ grade + Hmisc::rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0),
       data = na.omit(trial)
     ) %>%
       tbl_regression() %>%
       combine_terms(
-        formula_update = . ~ . - rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0)
-      ),
-    NA
+        formula_update = . ~ . - Hmisc::rcspline.eval(marker, nk = 4, inclx = TRUE, norm = 0)
+      ) %>%
+      render_as_html()
   )
 
   # Confirm GEE model works (as long as selected terms are not the only terms in model)
   # GEE does not work for comparison with null model
-  expect_error(
+  expect_snapshot(
     geepack::geeglm(
       as.formula("weight ~ Diet + Time + sp2Time + sp3Time"),
       data = ChickWeight %>%
@@ -128,8 +129,8 @@ test_that("combine_terms works without error", {
       tbl_regression() %>%
       combine_terms(
         formula_update = . ~ . - Time - sp2Time - sp3Time
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   expect_message(
