@@ -10,6 +10,7 @@ test_that("no errors/warnings with all output types", {
     tbl_summary() %>%
     modify_caption("test caption")
 
+  expect_snapshot(tbl %>% render_as_html())
   expect_error(tbl %>% as_gt(), NA)
   expect_error(tbl %>% as_flex_table(), NA)
   expect_error(tbl %>% as_hux_table(), NA)
@@ -21,7 +22,7 @@ test_that("no errors/warnings with all output types", {
     select(age) %>%
     tbl_summary() %>%
     modify_caption("test caption", text_interpret = "html")
-  expect_error(tbl2 %>% as_gt(), NA)
+  expect_snapshot(tbl2 %>% render_as_html())
 
   tbl_reg <- lm(mpg ~ hp, mtcars) %>% tbl_regression()
   expect_error(modify_caption(trial), "*")
@@ -37,9 +38,10 @@ test_that("no errors/warnings with all output types", {
       trial %>%
       select(age) %>%
       tbl_summary() %>%
-      modify_table_body(~rename(.x, label2 = label)) %>%
+      modify_table_body(~ rename(.x, label2 = label)) %>%
       modify_column_unhide(label2) %>%
       modify_caption("captions are great"),
     NA
   )
+  expect_snapshot(tbl_with_caption %>% render_as_html())
 })
