@@ -1,10 +1,10 @@
 skip_on_cran()
 
 test_that("modify_column_alignment() works", {
-  expect_error(
+  expect_snapshot(
     lm(age ~ marker + grade, trial) %>%
       tbl_regression() %>%
-      modify_column_alignment(columns = everything(), align = "left"),
-    NA
+      modify_column_alignment(columns = everything(), align = "left") %>%
+      render_as_html()
   )
 })
