@@ -11,6 +11,12 @@ test_that("no errors/warnings with standard use", {
   expect_error(sty2 <- style_percent(percent_vals, symbol = TRUE, digits = 1), NA)
   expect_warning(sty2, NA)
   expect_equal(sty2, c(NA, "0%", "<0.01%", "0.01%", "0.50%", "1.00%", "10.0%", "45.4%", "99.0%", "145.0%"))
+
+  vec2 <- c(one = 0.99, two = 0.0005)
+  expect_equal(
+    attributes(vec2),
+    style_percent(vec2) %>% attributes()
+  )
 })
 
 
