@@ -2,7 +2,8 @@ skip_on_cran()
 
 test_that("no errors with standard use", {
   expect_error(
-    trial %>%
+    tbl <-
+      trial %>%
       select(age, grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
       tbl_strata(
@@ -14,8 +15,9 @@ test_that("no errors with standard use", {
       ),
     NA
   )
+  expect_snapshot(tbl %>% render_as_html())
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       select(age, grade, stage, trt) %>%
       mutate(
@@ -28,12 +30,13 @@ test_that("no errors with standard use", {
           ~ .x %>%
             tbl_summary(by = trt) %>%
             add_p(test = all_continuous() ~ "t.test")
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   expect_error(
-    trial %>%
+    tbl <-
+      trial %>%
       select(age, grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
       tbl_strata(
@@ -44,9 +47,11 @@ test_that("no errors with standard use", {
       ),
     NA
   )
+  expect_snapshot(tbl %>% render_as_html())
 
   expect_error(
-    trial %>%
+    tbl <-
+      trial %>%
       select(age, grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
       tbl_strata(
@@ -59,8 +64,9 @@ test_that("no errors with standard use", {
       ),
     NA
   )
+  expect_snapshot(tbl %>% render_as_html())
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       select(age, grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
@@ -72,11 +78,11 @@ test_that("no errors with standard use", {
               y = age,
               method = lm
             )
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       select(grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
@@ -86,11 +92,11 @@ test_that("no errors with standard use", {
           ~ .x %>%
             tbl_cross() %>%
             add_p()
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       select(grade, stage, trt) %>%
       mutate(grade = paste("Grade", grade)) %>%
@@ -98,13 +104,13 @@ test_that("no errors with standard use", {
         strata = grade,
         .tbl_fun =
           ~ .x %>%
-          tbl_cross() %>%
-          add_p()
-      ),
-    NA
+            tbl_cross() %>%
+            add_p()
+      ) %>%
+      render_as_html()
   )
 
-  expect_error(
+  expect_snapshot(
     trial %>%
       select(grade, response) %>%
       tbl_strata2(
@@ -116,20 +122,20 @@ test_that("no errors with standard use", {
               label = list(response = .y),
               missing = "no"
             )
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   skip_if_not(broom.helpers::.assert_package("survey", pkg_search = "gtsummary", boolean = TRUE))
-  expect_error(
+  expect_snapshot(
     survey::svydesign(~1, data = trial, weights = ~1) %>%
       tbl_strata(
         strata = grade,
         ~ tbl_svysummary(.x, by = trt, include = c(stage, trt), percent = "cell") %>%
           modify_header(all_stat_cols() ~ "**{level}**"),
         .combine_with = "tbl_stack"
-      ),
-    NA
+      ) %>%
+      render_as_html()
   )
 
   # check .combine_args works, no spanning header anywhere
@@ -141,11 +147,12 @@ test_that("no errors with standard use", {
         strata = trt,
         .tbl_fun =
           ~ .x %>%
-          tbl_summary(),
+            tbl_summary(),
         .combine_args = list(tab_spanner = FALSE)
       ),
     NA
   )
+  expect_snapshot(tbl %>% render_as_html())
   expect_true(all(is.na(tbl$table_styling$header$spanning_header)))
 
   lifecycle::expect_deprecated(
@@ -155,10 +162,10 @@ test_that("no errors with standard use", {
         strata = trt,
         .tbl_fun =
           ~ .x %>%
-          tbl_summary(by = grade, missing = "no") %>%
-          add_n(),
+            tbl_summary(by = grade, missing = "no") %>%
+            add_n(),
         .stack_group_header = TRUE,
-        .combine_with = 'tbl_stack'
+        .combine_with = "tbl_stack"
       )
   )
 })
