@@ -6,9 +6,12 @@ data(api, package = "survey")
 dc_light <- survey::svydesign(id = ~dnum, weights = ~pw, data = apiclus1, fpc = ~fpc, variables = ~ stype + growth + both)
 
 test_that("tbl_svysummary creates output without error/warning (no by var)", {
-  expect_error(
-    purrr::map(list(d, dc_light), ~ tbl_svysummary(.x, sort = list(all_categorical() ~ "frequency"))),
-    NA
+  expect_snapshot(
+    purrr::map(
+      list(d, dc_light),
+      ~ tbl_svysummary(.x, sort = list(all_categorical() ~ "frequency")) %>%
+        as_tibble()
+    )
   )
   expect_warning(
     purrr::map(list(d, dc_light), ~ tbl_svysummary(.x)),
@@ -22,9 +25,8 @@ test_that("tbl_svysummary creates output without error/warning (with by var)", {
     all_continuous() ~ "{median} {mean} {sd} {var} {min} {max} {sum} {p25} {p42} {p75} {p89} {mean.std.error}",
     all_categorical() ~ "{n} {N} {p} | {n_unweighted} {N_unweighted} {p_unweighted}"
   )
-  expect_error(
-    tbl_svysummary(dc_light, by = both, statistic = statistics),
-    NA
+  expect_snapshot(
+    tbl_svysummary(dc_light, by = both, statistic = statistics) %>% render_as_html()
   )
   expect_warning(
     tbl_svysummary(dc_light, by = both, statistic = statistics),
@@ -33,9 +35,9 @@ test_that("tbl_svysummary creates output without error/warning (with by var)", {
 })
 
 test_that("tbl_svysummary allows for named list input", {
-  expect_error(
-    tbl_svysummary(d, by = Survived, label = list(Class = "New Class", Sex = "New Sex")),
-    NA
+  expect_snapshot(
+    tbl_svysummary(d, by = Survived, label = list(Class = "New Class", Sex = "New Sex")) %>%
+      render_as_html()
   )
   expect_warning(
     tbl_svysummary(d, by = Survived, label = list(Class = "New Class", Sex = "New Sex")),
@@ -56,29 +58,28 @@ test_that("tbl_svysummary throws errors/messages with bad 'sort = ' specificatio
 })
 
 test_that("tbl_svysummary value argument works properly", {
-  expect_error(
-    tbl_svysummary(d, value = "Class" ~ "1st"),
-    NA
+  expect_snapshot(
+    tbl_svysummary(d, value = "Class" ~ "1st") %>%
+      render_as_html()
   )
 })
 
 test_that("tbl_svysummary works in character inputs for `by=`", {
   my_by_variable <- "Survived"
 
-  expect_error(
-    tbl_svysummary(d, by = all_of(my_by_variable)),
-    NA
+  expect_snapshot(
+    tbl_svysummary(d, by = all_of(my_by_variable)) %>%
+      render_as_html()
   )
-  expect_error(
-    tbl_svysummary(d, by = "Survived"),
-    NA
+  expect_snapshot(
+    tbl_svysummary(d, by = "Survived") %>%
+      render_as_html()
   )
-  expect_error(
+  expect_snapshot(
     purrr::map(
       c("Survived", "Class", "Sex", "Age"),
-      ~ tbl_svysummary(d, by = all_of(.x))
-    ),
-    NA
+      ~ tbl_svysummary(d, by = all_of(.x)) %>% as_tibble()
+    )
   )
 })
 
@@ -166,6 +167,7 @@ test_that("tbl_svysummary-testing tidyselect parsing", {
       ),
     NA
   )
+  expect_snapshot(big_test %>% render_as_html())
 
   # checking missing
   expect_equal(
@@ -267,7 +269,8 @@ test_that("tbl_svysummary-order of output columns", {
       survey::svydesign(data = ., ids = ~1, weights = ~1) %>%
       tbl_svysummary(by = grade_str) %>%
       purrr::pluck("table_body") %>%
-      names() %>% {
+      names() %>%
+      {
         .[startsWith(., "stat_")]
       },
     paste0("stat_", 1:3)
@@ -279,23 +282,23 @@ test_that("tbl_svysummary-all_categorical() use with `type=`", {
   expect_true(
     !"dichotomous" %in%
       (survey::svydesign(data = trial, ids = ~1, weights = ~1) %>%
-         tbl_svysummary(type = all_dichotomous() ~ "categorical") %>%
-         purrr::pluck("meta_data") %>%
-         dplyr::pull(summary_type))
+        tbl_svysummary(type = all_dichotomous() ~ "categorical") %>%
+        purrr::pluck("meta_data") %>%
+        dplyr::pull(summary_type))
   )
 })
 
 
 test_that("tbl_svysummary-difftime does not cause error", {
-  expect_error(
+  expect_snapshot(
     dplyr::storms %>%
       dplyr::mutate(
         date = ISOdate(year, month, day),
         date_diff = difftime(dplyr::lag(date, 5), date, units = "days")
       ) %>%
       survey::svydesign(data = ., ids = ~1, weights = ~1) %>%
-      tbl_svysummary(),
-    NA
+      tbl_svysummary() %>%
+      render_as_html()
   )
 })
 
@@ -316,16 +319,18 @@ test_that("tbl_svysummary-all missing data does not cause error", {
     all_missing_no_by <- tbl_svysummary(design_missing, include = -my_by_var),
     NA
   )
+  expect_snapshot(all_missing_no_by %>% render_as_html())
 
   expect_error(
     all_missing_by <- tbl_svysummary(design_missing, by = my_by_var),
     NA
   )
+  expect_snapshot(all_missing_by %>% render_as_html())
 
   # making categorical, variables that cannot be summarized as categorical
-  expect_error(
-    tbl_svysummary(design_missing, by = my_by_var, type = vars(int, dbl) ~ "categorical"),
-    NA
+  expect_snapshot(
+    tbl_svysummary(design_missing, by = my_by_var, type = c(int, dbl) ~ "categorical") %>%
+      render_as_html()
   )
 
   expect_equal(
@@ -389,22 +394,22 @@ test_that("tbl_svysummary-all missing data does not cause error", {
 
 
 test_that("tbl_svysummary-no error when *data* with single column passed", {
-  expect_error(
+  expect_snapshot(
     trial["trt"] %>%
       as.data.frame() %>%
       survey::svydesign(data = ., ids = ~1, weights = ~1) %>%
-      tbl_svysummary(label = trt ~ "TREATMENT GROUP"),
-    NA
+      tbl_svysummary(label = trt ~ "TREATMENT GROUP") %>%
+      render_as_html()
   )
 })
 
 test_that("tbl_svysummary-no error when by variable is ordered factor", {
-  expect_error(
+  expect_snapshot(
     trial %>%
       dplyr::mutate(grade = as.ordered(grade)) %>%
       survey::svydesign(data = ., ids = ~1, weights = ~1) %>%
-      tbl_svysummary(by = grade),
-    NA
+      tbl_svysummary(by = grade) %>%
+      render_as_html()
   )
 })
 
@@ -513,6 +518,7 @@ test_that("tbl_summary(digits=) tests with fn inputs", {
       ),
     NA
   )
+  expect_snapshot(tbl_digits %>% render_as_html())
 
   # checking the display is correct
   expect_equal(
@@ -528,7 +534,8 @@ test_that("tbl_svysummary() works with date and date/time", {
       dates = as.Date("2021-02-20") + 1:10,
       times = as.POSIXct("2021-02-20 20:31:33 EST") + 1:10,
       group = 1:10 %% 2
-    ) %>% {
+    ) %>%
+    {
       survey::svydesign(~1, data = ., weights = ~1)
     }
 
@@ -536,6 +543,7 @@ test_that("tbl_svysummary() works with date and date/time", {
     tbl1 <- df_date %>% tbl_svysummary(),
     NA
   )
+  expect_snapshot(tbl1 %>% render_as_html())
 
   expect_equal(
     tbl1 %>% as_tibble() %>% select(last_col()) %>% dplyr::pull(),
@@ -547,6 +555,7 @@ test_that("tbl_svysummary() works with date and date/time", {
     tbl1 <- df_date %>% tbl_svysummary(type = everything() ~ "continuous", digits = everything() ~ month_year, include = -group),
     NA
   )
+  expect_snapshot(tbl1 %>% render_as_html())
 
   expect_equal(
     tbl1 %>% as_tibble() %>% select(last_col()) %>% dplyr::pull(),
@@ -568,6 +577,7 @@ test_that("tbl_svysummary() works with date and date/time", {
       ),
     NA
   )
+  expect_snapshot(tbl1 %>% render_as_html())
 
   expect_error(
     tbl2 <- df_date %>% tbl_svysummary(by = group),
@@ -578,9 +588,11 @@ test_that("tbl_svysummary() works with date and date/time", {
   # checking that formatting the unweighted proportion works
   data(api, package = "survey")
   dstrat <-
-    survey::svydesign(id = ~1, strata = ~stype,
-                      weights = ~pw, data = apistrat, fpc = ~fpc,
-                      variables = apistrat[, c("pcttest", "growth", "awards")])
+    survey::svydesign(
+      id = ~1, strata = ~stype,
+      weights = ~pw, data = apistrat, fpc = ~fpc,
+      variables = apistrat[, c("pcttest", "growth", "awards")]
+    )
   expect_equal(
     tbl_svysummary(
       data = dstrat,
@@ -608,25 +620,25 @@ test_that("tbl_svysummary() works with date and date/time", {
 })
 
 test_that("tbl_svysummary() works with 0/1 variables", {
-  expect_error(
-    survey::svydesign(data = trial, ids = ~ 1, weights = ~ 1) %>%
-      tbl_svysummary(include = response),
-    NA
+  expect_snapshot(
+    survey::svydesign(data = trial, ids = ~1, weights = ~1) %>%
+      tbl_svysummary(include = response) %>%
+      render_as_html()
   )
 })
 
 test_that("tbl_svysummary() works with a factor having only one levem", {
   d <- tibble(fct = factor(c("a", "a", "a", "a", "a"))) %>%
-    survey::svydesign(data = ., ids = ~ 1, weights = ~ 1)
+    survey::svydesign(data = ., ids = ~1, weights = ~1)
 
   expect_error(
     res <- d %>% tbl_svysummary(),
     NA
   )
+  expect_snapshot(res %>% render_as_html())
 
   expect_equal(
     res$table_body$stat_0,
     c(NA, "5 (100%)")
   )
 })
-
